# Telliot Feed Examples

## Project documentation:

- [Telliot Feed Examples](https://tellor-io.github.io/telliot-feed-examples/)

## Installation and Configuration:

- [Getting Started](https://tellor-io.github.io/telliot-feed-examples/getting-started/)

## Usage:

- [Usage](https://tellor-io.github.io/telliot-feed-examples/usage/)

## Examples

### Report legacy ID 41 once

1. Report using the CLI:
    ```
    telliot-examples --no-flashbots report -lid 41 --submit-once
    ```
2. Enter value when prompted.

### Report legacy ID 1 every 12 hours

1. Report using the CLI:
    ```
    telliot-examples report --legacy-id 1
    ```
